@@ -432,7 +432,7 @@ class TorchFitterBase:
             if self.verbose & (verbose_steps > 0) > 0:
                 if step % verbose_steps == 0:
                     print(
-                        f'Prediction Step {step}/{len(test_loader)}, ' +
+                        f'\rPrediction Step {step}/{len(test_loader)}, ' +
                         f'time: {(time.time() - t):.2f} secs,' +
                         f'ETA: {(len(test_loader)-step)*(time.time() - t)/(step+1):.2f}', end=''
                     )
